@@ -5,7 +5,7 @@ use Carp;
 use Parse::JCONF::Boolean qw(TRUE FALSE);
 use Parse::JCONF::Error;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 our $HashClass = 'Tie::IxHash';
 
 sub new {
@@ -61,7 +61,7 @@ sub _parse_space_and_comments {
 	
 	pos($$data_ref) = $$offset_ref;
 	
-	while ($$data_ref =~ /\G(?:(\n+)|\s|#[^\n]+)/gc) {
+	while ($$data_ref =~ /\G(?:(\n+)|\s|#[^\n]*)/gc) {
 		if (defined $1) {
 			$$line_ref += length $1;
 		}
